@@ -31,7 +31,7 @@ class MxitGA(object):
 			visitor.ip_address = request.headers['X-Forwarded-For']
 			#TODO: Persist sessions.
 			session = Session()
-			page = Page(request.url)
+			page = Page(request.path)
 			self.tracker.track_pageview(page, session, visitor)
 			print('Tracked page')
 		except Exception as e:
